pub struct Substance {}Trait Implementations
Sourceimpl Agent for Substance
impl Agent for Substance
type Context = SupervisorSession<Substance>
Sourcefn initialize(&mut self, _ctx: &mut Context<Self>) -> Next<Self>
fn initialize(&mut self, _ctx: &mut Context<Self>) -> Next<Self>
The
initialize method is called first when the actor starts.
It should return a Next state, which the actor will transition to. Read moreSourcefn begin(&mut self) -> Next<Self>
fn begin(&mut self) -> Next<Self>
The
begin method is an initialization method without context.
It is usually the most commonly used method to start the actor
in transactional mode by initiating finite state machine message processing. Read morefn interrupt(&mut self, ctx: &mut Context<Self>)
fn event<'life0, 'life1, 'async_trait>(
&'life0 mut self,
ctx: &'life1 mut Context<Self>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn failed(&mut self, err: Error, _ctx: &mut Context<Self>)
fn rollback<'life0, 'life1, 'async_trait>(
_this: Option<&'life0 mut Self>,
_err: Error,
_ctx: &'life1 mut Context<Self>,
) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn finalize(&mut self, _ctx: &mut Context<Self>)
fn end(&mut self)